==> mastapy-14.0.0b1.tar.gz: mastapy-14.0.0b1/mastapy/_private/utility/units_and_measurements/measurements/_1702.py <==
"""HeatTransferResistance"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.utility.units_and_measurements import _1652
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_HEAT_TRANSFER_RESISTANCE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "HeatTransferResistance"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="HeatTransferResistance")
    CastSelf = TypeVar(
        "CastSelf", bound="HeatTransferResistance._Cast_HeatTransferResistance"
    )


__docformat__ = "restructuredtext en"
__all__ = ("HeatTransferResistance",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_HeatTransferResistance:
    """Special nested class for casting HeatTransferResistance to subclasses."""

    __parent__: "HeatTransferResistance"

    @property
    def measurement_base(self: "CastSelf") -> "_1652.MeasurementBase":
        return self.__parent__._cast(_1652.MeasurementBase)

    @property
    def heat_transfer_resistance(self: "CastSelf") -> "HeatTransferResistance":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class HeatTransferResistance(_1652.MeasurementBase):
    """HeatTransferResistance

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _HEAT_TRANSFER_RESISTANCE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_HeatTransferResistance":
        """Cast to another type.

        Returns:
            _Cast_HeatTransferResistance
        """
        return _Cast_HeatTransferResistance(self)

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1702.py <==
"""FlowRate"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1666

_FLOW_RATE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "FlowRate"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="FlowRate")
    CastSelf = TypeVar("CastSelf", bound="FlowRate._Cast_FlowRate")


__docformat__ = "restructuredtext en"
__all__ = ("FlowRate",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FlowRate:
    """Special nested class for casting FlowRate to subclasses."""

    __parent__: "FlowRate"

    @property
    def measurement_base(self: "CastSelf") -> "_1666.MeasurementBase":
        return self.__parent__._cast(_1666.MeasurementBase)

    @property
    def flow_rate(self: "CastSelf") -> "FlowRate":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class FlowRate(_1666.MeasurementBase):
    """FlowRate

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FLOW_RATE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_FlowRate":
        """Cast to another type.

        Returns:
            _Cast_FlowRate
        """
        return _Cast_FlowRate(self)
